pub struct IbcTransferMsg {
pub transfer_msg: TransferMsg,
pub timeout_block_delta: Option<u64>,
pub timeout_timestamp_seconds_delta: Option<u64>,
}Fields
transfer_msg: TransferMsgtimeout_block_delta: Option<u64>timeout_timestamp_seconds_delta: Option<u64>Trait Implementations
Sourceimpl Clone for IbcTransferMsg
impl Clone for IbcTransferMsg
Sourcefn clone(&self) -> IbcTransferMsg
fn clone(&self) -> IbcTransferMsg
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IbcTransferMsg
impl Debug for IbcTransferMsg
Sourceimpl<'de> Deserialize<'de> for IbcTransferMsg
impl<'de> Deserialize<'de> for IbcTransferMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IbcTransferMsg
impl JsonSchema for IbcTransferMsg
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for IbcTransferMsg
impl PartialEq for IbcTransferMsg
Sourceimpl Serialize for IbcTransferMsg
impl Serialize for IbcTransferMsg
impl StructuralPartialEq for IbcTransferMsg