pub struct WithdrawAssetsMsg {
pub asset_infos: Vec<AssetInfo>,
}Fields
asset_infos: Vec<AssetInfo>Trait Implementations
Sourceimpl Clone for WithdrawAssetsMsg
impl Clone for WithdrawAssetsMsg
Sourcefn clone(&self) -> WithdrawAssetsMsg
fn clone(&self) -> WithdrawAssetsMsg
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WithdrawAssetsMsg
impl Debug for WithdrawAssetsMsg
Sourceimpl<'de> Deserialize<'de> for WithdrawAssetsMsg
impl<'de> Deserialize<'de> for WithdrawAssetsMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WithdrawAssetsMsg
impl JsonSchema for WithdrawAssetsMsg
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for WithdrawAssetsMsg
impl PartialEq for WithdrawAssetsMsg
Sourceimpl Serialize for WithdrawAssetsMsg
impl Serialize for WithdrawAssetsMsg
impl StructuralPartialEq for WithdrawAssetsMsg